/*
TIP 5: HOW TO SIMULATE DATA FROM A MULTIVARIATE DISTRIBUTION

Rick Wicklin, 2015, Paper SAS1387-2015
"Ten Tips for Simulating Data with SAS"
Proceedings of the SAS Global Forum 2015 Conference. 
Cary, NC: SAS Institute Inc.
*/
title; title2;

proc iml;
Mean = {1, 2, 3};               /* population means */
Cov = {3 2 1,                   /* population covariances */
       2 4 0,
       1 0 5};
N = 1000;                       /* sample size */
call randseed(123);
X = RandNormal(N, Mean, Cov);   /* x is a 1000 x 3 matrix */
SampleMean = mean(X);
SampleCov = cov(X);
varNames = "x1":"x3";
print SampleMean[colname=varNames],
      SampleCov[colname=varNames rowname=VarNames];

/* write sample to SAS data set for plotting */
create MVN from X[colname=varNames];  append from X;  close MVN;
quit;


/* create scatter plot matrix of simulated data */
proc corr data=MVN plots(maxpoints=NONE)=matrix(histogram);
   var x:;
run;
