/*
TIP 6: HOW TO EFFICIENTLY APPROXIMATE A SAMPLING DISTRIBUTION

Rick Wicklin, 2015, Paper SAS1387-2015
"Ten Tips for Simulating Data with SAS"
Proceedings of the SAS Global Forum 2015 Conference. 
Cary, NC: SAS Institute Inc.
*/
title; title2;

/* Step 1: Generate a data set that contains many samples */
%let N = 10;                      /* sample size */
%let NumSamples = 1000;           /* number of samples */
data Sim;
call streaminit(123);
do SampleID = 1 to &NumSamples;   /* ID variable for each sample */
   do i = 1 to &N;
      x = rand("Uniform");
      output;
   end;
end;
run;


/* Step 2: Compute the mean of each sample */
proc means data=Sim noprint;
   by SampleID;
   var x;
   output out=OutStats mean=SampleMean;
run;


/* Step 3: Visualize and compute descriptive statistics for the ASD */
ods select Moments Histogram;
proc univariate data=OutStats;
   label SampleMean = "Sample Mean of U(0,1) Data";
   var SampleMean;
   histogram SampleMean / normal;      /* overlay normal fit */
run;


%let N = 10;
%let NumSamples = 1000;
proc iml;
call randseed(123);
x = j(&NumSamples,&N);       /* many samples (rows), each of size N */
call randgen(x, "Uniform");  /* 1. Simulate data                    */
s = x[,:];                   /* 2. Compute statistic for each row   */
Mean = mean(s);              /* 3. Summarize and analyze ASD        */
StdDev = std(s);
call qntl(q, s, {0.05 0.95});
print Mean StdDev (q`)[colname={"5th Pctl" "95th Pctl"}];
quit;
