/*
TIP 9: HOW TO SIMULATE DATA TO ASSESS REGRESSION ESTIMATES

Rick Wicklin, 2015, Paper SAS1387-2015
"Ten Tips for Simulating Data with SAS"
Proceedings of the SAS Global Forum 2015 Conference. 
Cary, NC: SAS Institute Inc.
*/
title; title2;


%let N = 50;                                /* sample size */
data Explanatory(keep=x z);
call streaminit(12345);
do i = 1 to &N;
   x = rand("Normal");
   z = rand("Normal");
   output;
end;
run;


/* Simulate multiple samples from a regression model */
%let NumSamples = 1000;                     /* number of samples     */
data RegSim(drop=eta rmse);
call streaminit(123);
rmse = 1;                                   /* scale of error term   */
set Explanatory;                            /* implicit loop over obs*/
ObsNum = _N_;                               /* observation number    */
eta = 1 + X/2 + Z/3;                        /* linear predictor      */
do SampleID = 1 to &NumSamples;
   Y = eta + rand("Normal", 0, rmse);       /* random error term     */
   output;
end;
run;

proc sort data=RegSim;              /* sort for BY-group processing  */
   by SampleID ObsNum;
run;


proc reg data=RegSim outest=OutEst NOPRINT;
   by SampleID;
   model y = x z;
quit;

proc means nolabels data=OutEst Mean Std P5 P95;
   var Intercept x z;
run;

